==> jc-1.4.0.tar.gz: soot/JavaToJimpleBodyPack.h <==
// public class soot.JavaToJimpleBodyPack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cd3a66046895aece soot_BodyPack
// @dep_class c5e5ac7675bff53 soot_JavaToJimpleBodyPack
// @dep_class 65aca5ceab69719a soot_Pack

// header file dependencies
// @dep_header soot_BodyPack

#include "soot/BodyPack.h"

#ifndef _JC_soot_JavaToJimpleBodyPack_H_
#define _JC_soot_JavaToJimpleBodyPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_jimple_JimpleBody$object;

// Typedefs
typedef struct _jc_soot_JavaToJimpleBodyPack$sub_refs	_jc_soot_JavaToJimpleBodyPack$sub_refs;
typedef struct _jc_soot_JavaToJimpleBodyPack$sub_nonrefs	_jc_soot_JavaToJimpleBodyPack$sub_nonrefs;
typedef struct _jc_soot_JavaToJimpleBodyPack$refs	_jc_soot_JavaToJimpleBodyPack$refs;
typedef struct _jc_soot_JavaToJimpleBodyPack$nonrefs	_jc_soot_JavaToJimpleBodyPack$nonrefs;
typedef struct _jc_soot_JavaToJimpleBodyPack$object	_jc_soot_JavaToJimpleBodyPack$object;

typedef const struct _jc_soot_JavaToJimpleBodyPack$vmethods	_jc_soot_JavaToJimpleBodyPack$vmethods;
typedef const struct _jc_soot_JavaToJimpleBodyPack$vtable	_jc_soot_JavaToJimpleBodyPack$vtable;
typedef const struct _jc_soot_JavaToJimpleBodyPack$vtype	_jc_soot_JavaToJimpleBodyPack$vtype;

// Constructors
extern void _jc_soot_JavaToJimpleBodyPack$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *);

// Virtual methods
extern void _jc_soot_JavaToJimpleBodyPack$method$applyPhaseOptions$de899fce4e2f3d0e(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
extern void _jc_soot_JavaToJimpleBodyPack$method$internalApply$8c8b8fe09b775776(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_Body$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_JavaToJimpleBodyPack$method_info$applyPhaseOptions$de899fce4e2f3d0e;
extern _jc_method _jc_soot_JavaToJimpleBodyPack$method_info$internalApply$8c8b8fe09b775776;

// Virtual methods structure
struct _jc_soot_JavaToJimpleBodyPack$vmethods {
	void	(*applyPhaseOptions$de899fce4e2f3d0e)(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *);
	void	(*internalApply$8c8b8fe09b775776)(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_Body$object *);
};

// Vtable
struct _jc_soot_JavaToJimpleBodyPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_BodyPack$vmethods	soot_BodyPack;
	_jc_soot_JavaToJimpleBodyPack$vmethods	soot_JavaToJimpleBodyPack;
};

// Vtype
struct _jc_soot_JavaToJimpleBodyPack$vtype {
	_jc_type			type;
	_jc_soot_JavaToJimpleBodyPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_JavaToJimpleBodyPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_JavaToJimpleBodyPack$refs {
    _jc_soot_JavaToJimpleBodyPack$sub_refs	soot_JavaToJimpleBodyPack;
    _jc_soot_BodyPack$sub_refs	soot_BodyPack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_JavaToJimpleBodyPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_JavaToJimpleBodyPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_BodyPack$sub_nonrefs	soot_BodyPack;
    _jc_soot_JavaToJimpleBodyPack$sub_nonrefs	soot_JavaToJimpleBodyPack;
};

// Object instance structure
struct _jc_soot_JavaToJimpleBodyPack$object {
	_jc_soot_JavaToJimpleBodyPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_JavaToJimpleBodyPack$vtype	*vtype;
	_jc_soot_JavaToJimpleBodyPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_JavaToJimpleBodyPack$vtype _jc_soot_JavaToJimpleBodyPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_JavaToJimpleBodyPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_JavaToJimpleBodyPack$class_object;

#endif	/* _JC_soot_JavaToJimpleBodyPack_H_ */

==> jc-1.4.6.tar.gz: soot/JavaToJimpleBodyPack.h <==
// public class soot.JavaToJimpleBodyPack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cd3a66046895aece soot_BodyPack
// @dep_class c5e5ac7675bff53 soot_JavaToJimpleBodyPack
// @dep_class 65aca5ceab69719a soot_Pack

// header file dependencies
// @dep_header soot_BodyPack

#include "soot/BodyPack.h"

#ifndef _JC_soot_JavaToJimpleBodyPack_H_
#define _JC_soot_JavaToJimpleBodyPack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_jimple_JimpleBody$object;

// Typedefs
typedef struct _jc_soot_JavaToJimpleBodyPack$sub_refs	_jc_soot_JavaToJimpleBodyPack$sub_refs;
typedef struct _jc_soot_JavaToJimpleBodyPack$sub_nonrefs	_jc_soot_JavaToJimpleBodyPack$sub_nonrefs;
typedef struct _jc_soot_JavaToJimpleBodyPack$refs	_jc_soot_JavaToJimpleBodyPack$refs;
typedef struct _jc_soot_JavaToJimpleBodyPack$nonrefs	_jc_soot_JavaToJimpleBodyPack$nonrefs;
typedef struct _jc_soot_JavaToJimpleBodyPack$object	_jc_soot_JavaToJimpleBodyPack$object;

typedef const struct _jc_soot_JavaToJimpleBodyPack$vmethods	_jc_soot_JavaToJimpleBodyPack$vmethods;
typedef const struct _jc_soot_JavaToJimpleBodyPack$vtable	_jc_soot_JavaToJimpleBodyPack$vtable;
typedef const struct _jc_soot_JavaToJimpleBodyPack$vtype	_jc_soot_JavaToJimpleBodyPack$vtype;

// Constructors
extern void _jc_soot_JavaToJimpleBodyPack$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_JavaToJimpleBodyPack$method$applyPhaseOptions$de899fce4e2f3d0e(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_JavaToJimpleBodyPack$method$internalApply$8c8b8fe09b775776(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_JavaToJimpleBodyPack$method_info$applyPhaseOptions$de899fce4e2f3d0e;
extern _jc_method _jc_soot_JavaToJimpleBodyPack$method_info$internalApply$8c8b8fe09b775776;

// Virtual methods structure
struct _jc_soot_JavaToJimpleBodyPack$vmethods {
	void	(*applyPhaseOptions$de899fce4e2f3d0e)(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_jimple_JimpleBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*internalApply$8c8b8fe09b775776)(_jc_env *, struct _jc_soot_JavaToJimpleBodyPack$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_JavaToJimpleBodyPack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_BodyPack$vmethods	soot_BodyPack;
	_jc_soot_JavaToJimpleBodyPack$vmethods	soot_JavaToJimpleBodyPack;
};

// Vtype
struct _jc_soot_JavaToJimpleBodyPack$vtype {
	_jc_type			type;
	_jc_soot_JavaToJimpleBodyPack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_JavaToJimpleBodyPack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_JavaToJimpleBodyPack$refs {
    _jc_soot_JavaToJimpleBodyPack$sub_refs	soot_JavaToJimpleBodyPack;
    _jc_soot_BodyPack$sub_refs	soot_BodyPack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_JavaToJimpleBodyPack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_JavaToJimpleBodyPack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_BodyPack$sub_nonrefs	soot_BodyPack;
    _jc_soot_JavaToJimpleBodyPack$sub_nonrefs	soot_JavaToJimpleBodyPack;
};

// Object instance structure
struct _jc_soot_JavaToJimpleBodyPack$object {
	_jc_soot_JavaToJimpleBodyPack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_JavaToJimpleBodyPack$vtype	*vtype;
	_jc_soot_JavaToJimpleBodyPack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_JavaToJimpleBodyPack$vtype _jc_soot_JavaToJimpleBodyPack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_JavaToJimpleBodyPack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_JavaToJimpleBodyPack$class_object;

#endif	/* _JC_soot_JavaToJimpleBodyPack_H_ */
